# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Model import (
    IAvailableToolCategory,
    ICustomizeRibbonModel,
    ICustomizeRibbonTarget,
    ICustomizeWindowTarget,
)
from .Tools import ITool

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel

class CustomizeRibbonViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.ICustomizeRibbonViewModel,
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ICustomizeRibbonViewModel,
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.TaskViewModelBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask,
):  # Class
    def __init__(
        self,
        rootModel: Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.IControlPanelViewModel,
    ) -> None: ...

    SelectedToolFromProperty: System.Windows.DependencyProperty  # static
    SelectedToolToProperty: System.Windows.DependencyProperty  # static
    SelectedWindowTargetProperty: System.Windows.DependencyProperty  # static
    WindowTargetsProperty: System.Windows.DependencyProperty  # static

    AddCommand: System.Windows.Input.ICommand  # readonly
    Content: System.Windows.UIElement  # readonly
    IsEnabled: bool  # readonly
    MoveDownCommand: System.Windows.Input.ICommand  # readonly
    MoveUpCommand: System.Windows.Input.ICommand  # readonly
    NewButtonCommand: System.Windows.Input.ICommand  # readonly
    NewGroupCommand: System.Windows.Input.ICommand  # readonly
    NewMenuCommand: System.Windows.Input.ICommand  # readonly
    NewTabCommand: System.Windows.Input.ICommand  # readonly
    NewToolbarCommand: System.Windows.Input.ICommand  # readonly
    PropertiesCommand: System.Windows.Input.ICommand  # readonly
    RemoveCommand: System.Windows.Input.ICommand  # readonly
    SelectedToolFrom: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    )
    SelectedToolTo: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    )
    SelectedWindowTarget: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel
    )
    Title: str  # readonly
    WindowTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel
    ]
    _Model: ICustomizeRibbonModel  # readonly

    def CanNewTab(self, parameters: Any) -> bool: ...
    def NewGroup(self, parameters: Any) -> None: ...
    def NewToolbar(self, parameter: Any) -> None: ...
    def ResetToDefault(self) -> None: ...
    @overload
    @staticmethod
    def GetImage(
        tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase,
    ) -> System.Windows.Media.Imaging.BitmapSource: ...
    @overload
    @staticmethod
    def GetImage(image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def Reload(self) -> None: ...
    def CanNewGroup(self, parameters: Any) -> bool: ...
    def IsDirty(self) -> bool: ...
    def NewMenu(self, parameter: Any) -> None: ...
    def CanNewToolbar(self, parameter: Any) -> bool: ...
    def NewTab(self, parameters: Any) -> None: ...
    def NotifyTreeChanged(self) -> None: ...
    def CanNewMenu(self, parameter: Any) -> bool: ...
    def CanNewButton(self, parameter: Any) -> bool: ...
    def Activate(self) -> None: ...
    def NewButton(self, parameters: Any) -> None: ...
    def GetTools(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools: ...

class ICustomizeRibbonViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ICustomizeRibbonViewModel,
    Agilent.MassHunter.Quantitative.Startup.Edit.ViewModel.ITask,
):  # Interface
    AddCommand: System.Windows.Input.ICommand  # readonly
    MoveDownCommand: System.Windows.Input.ICommand  # readonly
    MoveUpCommand: System.Windows.Input.ICommand  # readonly
    NewButtonCommand: System.Windows.Input.ICommand  # readonly
    NewGroupCommand: System.Windows.Input.ICommand  # readonly
    NewMenuCommand: System.Windows.Input.ICommand  # readonly
    NewTabCommand: System.Windows.Input.ICommand  # readonly
    PropertiesCommand: System.Windows.Input.ICommand  # readonly
    RemoveCommand: System.Windows.Input.ICommand  # readonly
    SelectedToolFrom: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    )
    SelectedToolTo: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    )
    SelectedWindowTarget: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel
    )
    WindowTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel
    ]  # readonly
    _Model: ICustomizeRibbonModel  # readonly

    def NotifyTreeChanged(self) -> None: ...

class IRibbonTargetViewModel(object):  # Interface
    Children: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    ]  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly
    Target: ICustomizeRibbonTarget  # readonly

class IToolCategoryViewModel(object):  # Interface
    DisplayName: str  # readonly
    Name: str  # readonly
    Tools: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    ]  # readonly

class IToolViewModel(object):  # Interface
    Caption: str  # readonly
    Children: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    ]  # readonly
    Image: System.Windows.Media.ImageSource  # readonly
    IsExpanded: bool
    IsSelected: bool
    Parent: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    )  # readonly
    Tool: ITool  # readonly
    Tooltip: str  # readonly
    TooltipFooter: str  # readonly
    TypeImage: System.Windows.Media.ImageSource  # readonly

class IWindowTargetViewModel(object):  # Interface
    AvailableToolCategories: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolCategoryViewModel
    ]  # readonly
    CustomizeRibbonViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.ICustomizeRibbonViewModel
    )  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly
    RibbonTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IRibbonTargetViewModel
    ]  # readonly
    SelectedRibbonTarget: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IRibbonTargetViewModel
    )
    SelectedToolCategory: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolCategoryViewModel
    )
    Target: ICustomizeWindowTarget  # readonly

class RibbonTargetViewModel(
    System.Windows.DependencyObject,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IRibbonTargetViewModel,
):  # Class
    def __init__(
        self,
        viewModel: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel,
        target: ICustomizeRibbonTarget,
    ) -> None: ...

    ChildrenProperty: System.Windows.DependencyProperty  # static

    Children: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    ]
    DisplayName: str  # readonly
    Name: str  # readonly
    Target: ICustomizeRibbonTarget  # readonly

class ToolCategoryViewModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolCategoryViewModel
):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel,
        cat: IAvailableToolCategory,
    ) -> None: ...

    DisplayName: str  # readonly
    Name: str  # readonly
    Tools: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    ]  # readonly

class ToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...

class ToolViewModel(
    System.Windows.DependencyObject,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel,
):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel,
        tool: ITool,
    ) -> None: ...

    CaptionProperty: System.Windows.DependencyProperty  # static
    ChildrenProperty: System.Windows.DependencyProperty  # static
    ImageProperty: System.Windows.DependencyProperty  # static
    IsExpandedProperty: System.Windows.DependencyProperty  # static
    IsSelectedProperty: System.Windows.DependencyProperty  # static
    TooltipProperty: System.Windows.DependencyProperty  # static

    Caption: str  # readonly
    Children: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    ]
    Image: System.Windows.Media.ImageSource
    IsExpanded: bool
    IsSelected: bool
    Parent: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolViewModel
    )  # readonly
    Tool: ITool  # readonly
    Tooltip: str
    TooltipFooter: str  # readonly
    TooltipFooterVisibility: System.Windows.Visibility  # readonly
    TypeImage: System.Windows.Media.ImageSource  # readonly

class WindowTargetViewModel(
    System.Windows.DependencyObject,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IWindowTargetViewModel,
):  # Class
    def __init__(
        self,
        model: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.ICustomizeRibbonViewModel,
        target: ICustomizeWindowTarget,
    ) -> None: ...

    SelectedRibbonTargetProperty: System.Windows.DependencyProperty  # static # readonly
    SelectedToolCategoryProperty: System.Windows.DependencyProperty  # static # readonly

    AvailableToolCategories: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolCategoryViewModel
    ]  # readonly
    CustomizeRibbonViewModel: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.ICustomizeRibbonViewModel
    )  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly
    RibbonTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IRibbonTargetViewModel
    ]  # readonly
    SelectedRibbonTarget: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IRibbonTargetViewModel
    )
    SelectedToolCategory: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.ViewModel.IToolCategoryViewModel
    )
    Target: ICustomizeWindowTarget  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import SampleDataNavigator, TuneEvaluationMethod, TuneEvaluationResult

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI

class CommandLine:  # Class
    def __init__(self) -> None: ...

    MethodPath: str
    ReportPath: str
    SamplePath: str
    Silent: bool
    StatusPath: str

class DefaultEventManipulator(
    Agilent.MassSpectrometry.EventManipulating.Model.IEventManipulator,
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.DefaultEventManipulatorBase,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.EventManipulating.EventContext,
        mainForm: Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI.MainForm,
    ) -> None: ...
    def OnMouseDoubleClick(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...
    def OnMouseDown(
        self, sender: Any, e: System.Windows.Forms.MouseEventArgs
    ) -> None: ...

class MainForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

    EXT_DATA: str = ...  # static # readonly
    EXT_METHOD: str = ...  # static # readonly
    MZEXTRACTIONWINDOW_LEFT: float = ...  # static # readonly
    MZEXTRACTIONWINDOW_RIGHT: float = ...  # static # readonly
    TUNE_HELP_TOPICID: int = ...  # static # readonly
    UnifiedMethod_File: str = ...  # static # readonly
    UnifiedMethod_SubFolders: str = ...  # static # readonly

    DataNavigator: SampleDataNavigator
    MassHunterDir: str  # readonly
    Method: TuneEvaluationMethod
    Result: TuneEvaluationResult
    SamplePath: str
    SpectrumPane: Agilent.MassSpectrometry.GUI.Plot.Pane  # readonly
    SpectrumPlotControl: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI.SpectrumPlotControl
    )  # readonly
    TICPane: Agilent.MassSpectrometry.GUI.Plot.Pane  # readonly
    TICPlotControl: (
        Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI.TICPlotControl
    )  # readonly
    UnifiedMethodFolder: str

    def ShowExceptionMessage(self, ex: System.Exception) -> None: ...
    @staticmethod
    def ShowError(msg: str) -> None: ...
    def ClearResults(self) -> None: ...
    def RunTuneEvaluation(self) -> None: ...

class MarkerData(Agilent.MassSpectrometry.GUI.Plot.IMarkerData):  # Class
    def __init__(
        self, x: float, pane: Agilent.MassSpectrometry.GUI.Plot.Pane
    ) -> None: ...

class MethodForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(
        self,
        method: TuneEvaluationMethod,
        mainForm: Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI.MainForm,
    ) -> None: ...

    Method: TuneEvaluationMethod

class PlotData(
    System.IDisposable, Agilent.MassSpectrometry.GUI.Plot.IPlotData
):  # Class
    def __init__(self) -> None: ...

    NextColor: System.Drawing.Color  # readonly

    def GetPointCount(self, series: int) -> int: ...
    def GetSeriesCount(self) -> int: ...
    def DisplaySeries(self, series: int) -> bool: ...
    def RemoveSeries(self, index: int) -> None: ...
    def GetPoint(self, series: int, pointIndex: int, x: float, y: float) -> None: ...
    def GetYRange(self, minY: float, maxY: float) -> None: ...
    def AddSeries(
        self,
        color: System.Drawing.Color,
        mode: Agilent.MassSpectrometry.GUI.Plot.PlotModes,
        points: List[System.Drawing.PointF],
        title: str,
    ) -> None: ...
    def GetXRange(self, minX: float, maxX: float) -> None: ...
    def Dispose(self) -> None: ...
    def GetSeriesLineStyle(
        self,
        series: int,
        mode: Agilent.MassSpectrometry.GUI.Plot.PlotModes,
        color: System.Drawing.Color,
        style: System.Drawing.Drawing2D.DashStyle,
        width: int,
    ) -> None: ...

class SpectrumPlotControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class SpectrumPlotData(
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.IPeakData,
    Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI.PlotData,
    Agilent.MassSpectrometry.GUI.Plot.IPlotData,
):  # Class
    def __init__(self, xArray: List[float], yArray: List[float]) -> None: ...
    def Dispose(self) -> None: ...

class TICPlotControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    Agilent.MassSpectrometry.GUI.Plot.PlotControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...

class TICPlotData(
    System.IDisposable,
    Agilent.MassSpectrometry.GUI.Plot.IPeakData,
    Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI.PlotData,
    Agilent.MassSpectrometry.GUI.Plot.IPlotData,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, dataNavigator: SampleDataNavigator) -> None: ...

    PeakList: System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.IChromPeak
    ]

class TuneEvalMethodFileDialog(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogBase,
):  # Class
    def __init__(
        self,
        type: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Dialogs.ShellFileDialogType,
        extFolderName: str,
    ) -> None: ...

class TuneEvaluationReport:  # Class
    @overload
    def __init__(
        self,
        mainForm: Agilent.MassSpectrometry.DataAnalysis.TuneEvaluation.UI.MainForm,
        result: TuneEvaluationResult,
    ) -> None: ...
    @overload
    def __init__(
        self, samplePath: str, unifiedTuneMathodPath: str, result: TuneEvaluationResult
    ) -> None: ...

    PreferredPageSize: str

    def Process(self, file: str) -> None: ...
    def Dispose(self) -> None: ...

class Utils:  # Class
    @staticmethod
    def RegisterFont(name: str) -> None: ...
    @staticmethod
    def GetFont(name: str) -> iTextSharp.text.Font: ...
    @staticmethod
    def GetDefaultPageSize() -> iTextSharp.text.Rectangle: ...
    @staticmethod
    def GetDefaultFontNameByCulture(ci: System.Globalization.CultureInfo) -> str: ...
    @staticmethod
    def GetPageSize(name: str) -> iTextSharp.text.Rectangle: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Discovered Generic TypeVars:
TProviderInterface = TypeVar("TProviderInterface")
from .Interfaces import IDataProviderFactory, IProvider

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Providers

class DataProviderFactory(IDataProviderFactory):  # Class
    Instance: (
        Agilent.OpenLab.Framework.DataAccess.AcamlInfrastructure.Providers.DataProviderFactory
    )  # static # readonly

    @overload
    def GetProviderSet(self, docId: System.Guid) -> Iterable[IProvider]: ...
    @overload
    def GetProviderSet(
        self, acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML
    ) -> Iterable[IProvider]: ...
    @overload
    def GetProvider(self, docId: System.Guid) -> TProviderInterface: ...
    @overload
    def GetProvider(
        self, acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML
    ) -> TProviderInterface: ...
    def IsRegistered(
        self, acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML
    ) -> bool: ...
    def RegisterAcaml(
        self,
        acaml: Agilent.OpenLab.Framework.DataAccess.AcamlObjectModel.IACAML,
        prepareForWriteAccess: bool,
    ) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools

class ApplicationMenu2010(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolsBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IApplicationMenu2010,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        appMenu: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...
    def Insert(
        self,
        child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
        after: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    ) -> None: ...
    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...

class ApplicationMenu2010Item(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IApplicationMenu2010Item,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        item: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010Item,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

class ApplicationMenu2010ItemSeparator(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IApplicationMenu2010Item,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        separator: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ApplicationMenu2010ItemSeparator,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

    Caption: str  # readonly

class Button(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IButton,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        button: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Button,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

class CheckButton(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ICheckButton,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IButton,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        button: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.CheckButton,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

class ComboBox(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IComboBox,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        comboBox: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ComboBox,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

class ContextMenu(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolsBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IContextMenu,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        contextMenu: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ContextMenu,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

    Caption: str  # readonly

    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...

class Group(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolsBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IGroup,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        group: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Group,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...
    def Insert(
        self,
        child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
        after: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    ) -> None: ...
    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...

class IApplicationMenu2010(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
):  # Interface
    ...

class IApplicationMenu2010Item(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
):  # Interface
    ...

class IButton(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
):  # Interface
    ...

class ICheckButton(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IButton,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
):  # Interface
    ...

class IComboBox(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
):  # Interface
    ...

class IContextMenu(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
):  # Interface
    ...

class IGroup(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
):  # Interface
    ...

class ILabel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
):  # Interface
    ...

class IMenu(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
):  # Interface
    ...

class ISeparator(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
):  # Interface
    ...

class ITabItem(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
):  # Interface
    ...

class ITextBox(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
):  # Interface
    ...

class ITool(object):  # Interface
    Caption: str
    LargeImage: str
    Parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools  # readonly
    SmallImage: str
    Tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase  # readonly
    ToolString: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString
    )  # readonly
    Tooltip: str

    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...

class IToolString(object):  # Interface
    @overload
    def GetToolbarCaption(
        self, toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolbarDef
    ) -> str: ...
    @overload
    def GetToolbarCaption(self, id: str) -> str: ...
    def GetCategoryDisplayName(self, category: str) -> str: ...
    @overload
    def GetToolTooltip(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
    ) -> str: ...
    @overload
    def GetToolTooltip(self, id: str) -> str: ...
    def GetContextMenuDisplayName(self, id: str) -> str: ...
    @overload
    def GetToolCaption(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
    ) -> str: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...

class IToolbar(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
):  # Interface
    ...

class ITools(object):  # Interface
    Children: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ]  # readonly

    def MoveDown(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> None: ...
    def MoveUp(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> None: ...
    def CanMoveDown(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> bool: ...
    def CanInsert(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> bool: ...
    def Remove(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> None: ...
    def Insert(
        self,
        child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
        after: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    ) -> None: ...
    def CanMoveUp(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> bool: ...

class IWrapPanel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
):  # Interface
    ...

class Label(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ILabel,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        label: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Label,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

class Menu(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolsBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IMenu,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        menu: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Menu,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...
    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...

class Separator(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ISeparator,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        separator: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Separator,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

    Caption: str  # readonly

class TabItem(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolsBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITabItem,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        item: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.TabItem,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...
    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...
    def CanInsert(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> bool: ...

class TextBox(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITextBox,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        textBox: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.TextBox,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

class ToolBase(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    Caption: str
    LargeImage: str
    Parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools  # readonly
    SmallImage: str
    Tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase  # readonly
    ToolString: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString
    )  # readonly
    Tooltip: str

    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...

class Toolbar(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolsBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolbar,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolbarDef,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

    Caption: str  # readonly

    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...

class ToolsBase(
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolBase,
):  # Class
    Children: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ]  # readonly

    def MoveDown(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> None: ...
    def MoveUp(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> None: ...
    def CanMoveDown(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> bool: ...
    def CanInsert(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> bool: ...
    def Remove(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> None: ...
    def Insert(
        self,
        child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
        after: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    ) -> None: ...
    def CanMoveUp(
        self, child: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool
    ) -> bool: ...

class WrapPanel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ToolsBase,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITool,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IWrapPanel,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
    System.ComponentModel.INotifyPropertyChanged,
):  # Class
    def __init__(
        self,
        parent: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.ITools,
        wrapPanel: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.WrapPanel,
        toolString: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Tools.IToolString,
    ) -> None: ...

    Caption: str  # readonly

    def Commit(
        self,
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.OpenLab.Framework.Common.CustomAttributes

class SetpointsBindingAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, setpointContainerType: System.Type) -> None: ...

    SetpointContainerType: System.Type  # readonly

class UIBindingAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    @overload
    def __init__(self, transformationUIType: System.Type) -> None: ...
    @overload
    def __init__(
        self, transformationUIType: System.Type, displayOrder: int
    ) -> None: ...

    DisplayOrder: int  # readonly
    TransformationUIType: System.Type  # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Toolbar2 import MouseAction, MouseActionMap

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar

class AddRibbon(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomToolElementBase
):  # Class
    def __init__(self) -> None: ...

    ApplicationMenu: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonToolsDefinition
    )
    Pane: str
    QuickAccessToolar: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonToolsDefinition
    )
    TabItemToolbar: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonToolsDefinition
    )
    Tabs: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonTabDefinition
    ]

class ApplicationMenuAreaImpl(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IApplicationMenuArea
):  # Class
    ...

class ApplicationMenuImpl(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IApplicationMenu,
):  # Class
    Appearance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance
    )  # readonly
    Bounds: System.Drawing.Rectangle  # readonly
    Enabled: bool
    Executing: bool
    Id: str  # readonly
    Tooltip: str

class ButtonDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.MenuDefinition
):  # Class
    def __init__(self) -> None: ...

class CategoryScriptToolHandler(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CategoryToolHandler,
):  # Class
    def __init__(self) -> None: ...

    Execute: str
    SetState: str
    ToolHandlerType: System.Type  # static

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class CategoryToolHandler(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.TypeToolHandler,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...

    Category: str

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class CheckButtonDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ButtonDefinition
):  # Class
    def __init__(self) -> None: ...

    MenuDisplayStyle: Infragistics.Win.UltraWinToolbars.StateButtonMenuDisplayStyle
    ToolbarDisplayStyle: (
        Infragistics.Win.UltraWinToolbars.StateButtonToolbarDisplayStyle
    )

    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...

class CheckToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ICheckToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
):  # Class
    def __init__(self) -> None: ...

    Checked: bool

class ComboBoxDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ButtonDefinition
):  # Class
    def __init__(self) -> None: ...

    MaxDropDownItems: int
    Spring: bool

class ComboBoxToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IComboBoxToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
):  # Class
    IsDroppedDown: bool  # readonly
    ItemCount: int  # readonly
    SelectedIndex: int
    SelectedItem: Any

    def ClearItems(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def GetItemValue(self, index: int) -> Any: ...
    def IndexOf(self, value_: Any) -> int: ...
    def Remove(self, item: Any) -> None: ...
    def GetItemDisplayText(self, index: int) -> str: ...
    def AddItem(self, item: Any, displayText: str) -> None: ...
    def CloseDropdown(self) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class ContextMenuDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.PopupMenuDefinition
):  # Class
    def __init__(self) -> None: ...

class ContextualTabGroupDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    Tabs: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonTabDefinition
    ]

    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        ribbon: Infragistics.Win.UltraWinToolbars.Ribbon,
    ) -> None: ...

class CustomToolElementBase:  # Class
    Id: str
    Instrument: str

class CustomTools:  # Class
    def __init__(self) -> None: ...

    Elements: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomToolElementBase
    ]

    @overload
    @staticmethod
    def Evaluate(
        stream: System.IO.Stream,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        instrument: str,
    ) -> None: ...
    @overload
    @staticmethod
    def Evaluate(
        stream: System.IO.Stream,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        instrument: str,
        explorerBar: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBar,
    ) -> None: ...
    @overload
    @staticmethod
    def Evaluate(
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        instrument: str,
        explorerBar: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBar,
    ) -> None: ...

class ExplorerBarDefinition:  # Class
    def __init__(self) -> None: ...

    Groups: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ExplorerBarGroup
    ]

class ExplorerBarGroup:  # Class
    def __init__(self) -> None: ...

    Expanded: bool
    Id: str
    LargeImage: str
    Tools: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
    ]

class ExplorerBarItemState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ICheckToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
):  # Class
    def __init__(self) -> None: ...

    Appearance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance
    )  # readonly
    Bounds: System.Drawing.Rectangle  # readonly
    Checked: bool
    Enabled: bool
    Id: str  # readonly
    Tooltip: str

class IApplicationMenu(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState
):  # Interface
    ToolAreaRight: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IApplicationMenuArea
    )  # readonly

    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        register: bool,
    ) -> None: ...

class IApplicationMenuArea(object):  # Interface
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def Clear(self) -> None: ...
    def Add(self, id: str) -> None: ...
    def Remove(self, id: str) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class ICheckToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState
):  # Interface
    Checked: bool

class IComboBoxToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState
):  # Interface
    IsDroppedDown: bool  # readonly
    ItemCount: int  # readonly
    SelectedIndex: int
    SelectedItem: Any

    def ClearItems(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def GetItemValue(self, index: int) -> Any: ...
    def IndexOf(self, value_: Any) -> int: ...
    def Remove(self, item: Any) -> None: ...
    def GetItemDisplayText(self, index: int) -> str: ...
    def AddItem(self, item: Any, displayText: str) -> None: ...
    def CloseDropdown(self) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class IExplorerBarGroup(object):  # Interface
    Expanded: bool
    Id: str  # readonly

    def Add(self, id: str) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Exists(self, id: str) -> bool: ...
    def Insert(self, index: int, id: str) -> None: ...

class IPopupMenuToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState
):  # Interface
    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def Add(self, id: str) -> None: ...
    def ShowPopupMenu(self) -> None: ...
    def BeforeToolDropdown(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolBeforeDropdownHandler,
        add: bool,
    ) -> None: ...
    def Clear(self) -> None: ...
    def IndexOf(self, id: str) -> int: ...
    def Remove(self, id: str) -> None: ...
    def Exists(self, id: str) -> bool: ...
    def Insert(self, id: str, index: int) -> None: ...
    def InsertSeparator(self, index: int) -> None: ...
    def RemoveAt(self, index: int) -> None: ...

class IRibbon(object):  # Interface
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...
    TabCount: int  # readonly

    def RemoveTab(self, id: str) -> None: ...
    def ContainsTab(self, id: str) -> bool: ...
    def AddTab(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...
    def InsertTabAfter(
        self, id: str, idAfter: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTab: ...

class IRibbonGroup(object):  # Interface
    Caption: str
    ID: str  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    ItemCount: int  # readonly
    Tooltip: str
    Visible: bool

    def InsertToolAfter(
        self, id: str, idAfter: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def RemoveTool(self, id: str) -> None: ...
    def AddTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def ContainsTool(self, id: str) -> bool: ...

class IRibbonTab(object):  # Interface
    Caption: str
    GroupCount: int  # readonly
    ID: str  # readonly
    def __getitem__(
        self, index: int
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...
    Visible: bool

    def RemoveGroup(self, id: str) -> None: ...
    def ContainsGroup(self, id: str) -> bool: ...
    def AddGroup(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...
    def InsertGroupAfter(
        self, id: str, idAfter: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonGroup: ...

class IRibbonTabState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState
):  # Interface
    Visible: bool

class IScriptToolHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Interface
    ExecuteExpression: str
    SetStateExpression: str

class ITextBoxToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState
):  # Interface
    IsInEdit: bool  # readonly
    IsReadOnly: bool
    Text: str

class IToolAppearance(object):  # Interface
    BoldText: bool
    DisplayStyle: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    )
    DisplayText: str
    Image: str
    MaxWidth: int
    MinWidth: int
    Separator: bool
    Tooltip: str
    Width: int

class IToolBeforeDropdownHandler(object):  # Interface
    def Dropdown(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...

class IToolHandler(object):  # Interface
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiState: Any,
    ) -> None: ...

class IToolState(object):  # Interface
    Appearance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance
    )  # readonly
    Bounds: System.Drawing.Rectangle  # readonly
    Enabled: bool
    Executing: bool  # readonly
    Id: str  # readonly
    Tooltip: str

class IToolbar(object):  # Interface
    Caption: str  # readonly
    IsMenuBar: bool  # readonly
    Visible: bool

    def Contains(self, id: str) -> bool: ...
    def AddTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance: ...
    def InsertToolAfter(
        self, id: str, after: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance: ...
    def RemoveTool(self, id: str) -> None: ...
    def GetTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance: ...
    def GetToolState(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...

class IToolbarsManager(object):  # Interface
    Ribbon: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbon
    )  # readonly
    TouchEnabled: bool

    def RegisterCheckButton(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def GetApplicationMenu(
        self, paneId: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IApplicationMenu
    ): ...
    def SetToolImage(self, id: str, image: System.Drawing.Image) -> None: ...
    def RegisterPopupMenu(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def GetToolbarIds(self, pane: str) -> List[str]: ...
    def InvokeMouseAction(
        self, pane: str, button: str, mact: MouseAction, state: str
    ) -> None: ...
    def GetTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def RegisterToolHandler(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    def RemoveToolbar(self, paneId: str, toolbarId: str) -> None: ...
    def ContainsTool(self, id: str) -> bool: ...
    def Execute(
        self,
        state: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    ) -> None: ...
    def ContainsCategoryHandler(self, category: str) -> bool: ...
    def RegisterLabel(
        self, id: str, category: str, caption: str, tooltip: str
    ) -> None: ...
    def RegisterComboBox(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def GetToolbar(
        self, paneId: str, toolbarId: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbar: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def AddToolbar(
        self, paneId: str, toolbarId: str, text: str, row: int, column: int
    ) -> None: ...
    def RemoveTool(self, id: str) -> None: ...
    def ContainsToolbar(self, paneId: str, toolbarId: str) -> bool: ...
    def RegisterCategoryHandler(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    def RegisterButton(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...

    ToolExecuting: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolExecuteEventArgs
    ]  # Event

class InsertTool(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomToolElementBase
):  # Class
    def __init__(self) -> None: ...

    After: str
    Caption: str
    Category: str
    Checkbox: bool
    ComboBox: bool
    Label: bool
    Pane: str
    Parent: str
    RibbonGroup: str
    ScriptExecute: str
    ScriptModule: str
    ScriptSetState: str
    Toolbar: str
    Tooltip: str

class LabelDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ButtonDefinition
):  # Class
    def __init__(self) -> None: ...

class MenuBarDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarDefinition
):  # Class
    def __init__(self) -> None: ...

class MenuDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolCollectionDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    BoldText: bool
    Category: str
    DropDownArrowStyle: Infragistics.Win.UltraWinToolbars.DropDownArrowStyle
    Image: str
    ImageLarge: str
    PreferredSizeOnRibbon: Infragistics.Win.UltraWinToolbars.RibbonToolSize
    ScriptExecute: str
    ScriptModule: str
    ScriptSetState: str
    Shortcut: System.Windows.Forms.Shortcut
    Style: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    Visible: bool

    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        toolbarsMgr: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...

class PopupMenuDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.MenuDefinition
):  # Class
    def __init__(self) -> None: ...

class PopupMenuToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IPopupMenuToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
):  # Class
    def Insert(self, id: str, index: int) -> None: ...
    def InsertSeparator(self, index: int) -> None: ...
    def Add(self, id: str) -> None: ...

class RadioButtonDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ButtonDefinition
):  # Class
    def __init__(self) -> None: ...

    Group: str

    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...

class RemoveTool(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomToolElementBase
):  # Class
    def __init__(self) -> None: ...

    Parent: str

class RemoveToolbar(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomToolElementBase
):  # Class
    def __init__(self) -> None: ...

    Pane: str

class RibbonDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarDefinition
):  # Class
    def __init__(self) -> None: ...

    ApplicationMenu: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonToolsDefinition
    )
    ApplicationMenu2010: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonToolsDefinition
    )
    ContextualTabGroups: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ContextualTabGroupDefinition
    ]
    QuickAccessToolbar: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonToolsDefinition
    )
    TabItemToolbar: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonToolsDefinition
    )
    Tabs: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonTabDefinition
    ]

    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...

class RibbonGroupDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    LayoutDirection: Infragistics.Win.UltraWinToolbars.RibbonGroupToolLayoutDirection
    Tools: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
    ]

    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        groups: Infragistics.Win.UltraWinToolbars.RibbonGroupCollection,
    ) -> None: ...

class RibbonTabDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    Category: str
    Groups: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.RibbonGroupDefinition
    ]

    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        tabs: Infragistics.Win.UltraWinToolbars.RibbonTabCollectionBase,
    ) -> Infragistics.Win.UltraWinToolbars.RibbonTab: ...

class RibbonTabState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbonTabState,
):  # Class
    def __init__(self, tab: Infragistics.Win.UltraWinToolbars.RibbonTab) -> None: ...

    Appearance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance
    )  # readonly
    Bounds: System.Drawing.Rectangle  # readonly
    Enabled: bool
    Executing: bool  # readonly
    Id: str  # readonly
    Tooltip: str
    Visible: bool

class RibbonToolsDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.MenuDefinition
):  # Class
    def __init__(self) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...

class SeparatorDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...

class SetHandler(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CustomToolElementBase
):  # Class
    def __init__(self) -> None: ...

    ScriptExecute: str
    ScriptModule: str
    ScriptSetState: str

class SystemToolDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    Image: str

    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...

class TextBoxDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ButtonDefinition
):  # Class
    def __init__(self) -> None: ...

    Spring: bool

class TextBoxToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ITextBoxToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
):  # Class
    def __init__(self) -> None: ...

class ToolCollectionDefinitionBase(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
):  # Class
    Tools: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase
    ]

class ToolDefinitionAssemblyAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self) -> None: ...

    MethodNavigatorResourceName: str
    ToolDefinitionResourceName: str
    ToolResourceName: str

    @overload
    @staticmethod
    def LoadDefinitions(
        stream: System.IO.Stream,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitions: ...
    @overload
    @staticmethod
    def LoadDefinitions(
        assembly: System.Reflection.Assembly,
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitions: ...
    @staticmethod
    def GetAttribute(
        assembly: System.Reflection.Assembly,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionAssemblyAttribute
    ): ...
    def LoadMethodDefinitions(
        self, assembly: System.Reflection.Assembly
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ExplorerBarDefinition
    ): ...
    def GetToolResource(
        self, assembly: System.Reflection.Assembly
    ) -> System.Resources.ResourceManager: ...

class ToolDefinitionBase:  # Class
    Caption: str
    Customizable: bool
    Id: str
    MaxWidth: int
    MinWidth: int
    Tooltip: str
    Width: int

    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...

class ToolDefinitions:  # Class
    def __init__(self) -> None: ...

    CategoryToolHandlers: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CategoryToolHandler
    ]
    ContextMenus: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ContextMenuDefinition
    ]
    MouseActionMaps: List[MouseActionMap]
    ToolHandlers: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolHandler
    ]
    Toolbars: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarDefinition
    ]

class ToolDisplayStyle(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Default: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    ) = ...  # static # readonly
    ImageAndText: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    ) = ...  # static # readonly
    ImageOnly: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    ) = ...  # static # readonly
    TextOnly: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDisplayStyle
    ) = ...  # static # readonly

class ToolExecuteEventArgs(System.ComponentModel.CancelEventArgs):  # Class
    def __init__(self, id: str) -> None: ...

    ID: str  # readonly

class ToolHandler(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.TypeToolHandler,
):  # Class
    def __init__(self) -> None: ...

    Id: str

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class ToolHandlerBase(System.IDisposable):  # Class
    def Dispose(self) -> None: ...

class ToolScriptToolHandler(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolHandler,
):  # Class
    def __init__(self) -> None: ...

    Execute: str
    SetState: str
    ToolHandlerType: System.Type  # static

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class ToolState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolStateBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
):  # Class
    def __init__(self) -> None: ...

    Appearance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolAppearance
    )  # readonly
    Bounds: System.Drawing.Rectangle  # readonly
    Enabled: bool
    Id: str  # readonly
    Tooltip: str

class ToolStateBase(System.MarshalByRefObject):  # Class
    def __init__(self) -> None: ...

    Executing: bool

class ToolbarDefinition(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolCollectionDefinitionBase
):  # Class
    def __init__(self) -> None: ...

    Column: int
    Pane: str
    Row: int
    Visible: bool

    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
    ) -> None: ...
    @overload
    def AddTo(
        self, tools: Infragistics.Win.UltraWinToolbars.ToolsCollection
    ) -> None: ...
    @overload
    def AddTo(
        self,
        manager: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolbarsManagerBase,
        group: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBarGroup,
    ) -> None: ...

class ToolbarsManagerBase(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Forms.IMessageFilter,
):  # Class
    ActiveToolId: str  # readonly
    ApplicationType: str  # readonly
    Customizable: bool
    InstrumentType: str  # readonly
    Ribbon: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IRibbon
    )  # readonly
    SynchronizeInvoke: System.ComponentModel.ISynchronizeInvoke  # readonly
    ToolbarStyle: Infragistics.Win.UltraWinToolbars.ToolbarStyle
    TouchEnabled: bool

    def SetPaneControl(
        self, paneId: str, control: System.Windows.Forms.Control
    ) -> None: ...
    def AddPane(self, paneId: str, control: System.Windows.Forms.Control) -> None: ...
    def ContainsToolHandler(self, id: str) -> bool: ...
    def RegisterCheckButton(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def EndInit(self) -> None: ...
    def GetApplicationMenu(
        self, pane: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IApplicationMenu
    ): ...
    def SetToolImage(self, id: str, image: System.Drawing.Image) -> None: ...
    def Dispose(self) -> None: ...
    def RegisterPopupMenu(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def SetupExplorerBar(
        self,
        explorerBar: Infragistics.Win.UltraWinExplorerBar.UltraExplorerBar,
        definition: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ExplorerBarDefinition,
        resourceMgr: System.Resources.ResourceManager,
    ) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    def GetToolbarIds(self, paneId: str) -> List[str]: ...
    def AddTool(
        self,
        definition: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitionBase,
    ) -> None: ...
    def InvokeMouseAction(
        self, pane: str, button: str, mact: MouseAction, state: str
    ) -> None: ...
    def GetTool(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState: ...
    def SetupToolbars(
        self,
        definitions: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolDefinitions,
        assembly: System.Reflection.Assembly,
        resourceMgr: System.Resources.ResourceManager,
    ) -> None: ...
    def RegisterToolHandler(
        self,
        id: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    def BeginInit(self) -> None: ...
    def RemoveToolbar(self, paneId: str, toolbarId: str) -> None: ...
    def ContainsTool(self, id: str) -> bool: ...
    def Execute(
        self,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
    ) -> None: ...
    def FindToolByShortcut(self, sc: System.Windows.Forms.Shortcut) -> str: ...
    def ContainsCategoryHandler(self, id: str) -> bool: ...
    def RegisterLabel(
        self, id: str, category: str, caption: str, tooltip: str
    ) -> None: ...
    def LoadState(self, path: str) -> None: ...
    def GetPaneIds(self) -> List[str]: ...
    def RegisterComboBox(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...
    def GetToolbar(
        self, pane: str, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbar: ...
    def RegisterScriptToolHandler(
        self, toolid: str, module: str, setState: str, execute: str
    ) -> None: ...
    def SaveState(self, path: str) -> None: ...
    def RemoveCategoryHandler(self, id: str) -> None: ...
    def UpdateToolbarsStates(self) -> None: ...
    def AddToolHandler(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolHandler,
    ) -> None: ...
    def AddToolbar(
        self, paneId: str, toolbarId: str, text: str, row: int, column: int
    ) -> None: ...
    def RemoveTool(self, id: str) -> None: ...
    def AddCategoryHandler(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.CategoryToolHandler,
    ) -> None: ...
    def ContainsToolbar(self, paneId: str, toolbarId: str) -> bool: ...
    def RegisterCategoryHandler(
        self,
        category: str,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...
    def RegisterButton(
        self, id: str, category: str, caption: str, tooltipText: str
    ) -> None: ...

    ToolExecuting: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolExecuteEventArgs
    ]  # Event

class TypeToolHandler(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.ToolHandlerBase,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        handler: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler,
    ) -> None: ...

    Type: str

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Agilent.MassSpectrometry.DataAnalysis import (
    IFunction,
    IModificationSpecies,
    IModificationUnit,
    SpectralPeak,
    SpectralPeakFinderParameters,
)
from .Agilent.MassSpectrometry.DataAnalysis.MassHunter import (
    IChemicalAndIonizationParameters,
    IDataRangeParameters,
    IIonSpeciesGroupingRules,
    IProteinFinderParameters,
    IRetentionTimePeakFinderParameters,
    ITargetedMassList,
    SpectrumSetMetadata,
)
from .BasicTypes import (
    ICompoundPrecursorProductDataSet,
    MSProfile,
    PeakList,
    PrecursorIsotopeClusterExtractor,
)
from .Definitions import IMass_TimeSeparatedObject

# Stubs for namespace: Mfe

class Bucket:  # Class
    def __init__(
        self,
        sampleCount: int,
        standardType: Mfe.ObjectCorrelator.StandardUsage,
        time: float,
    ) -> None: ...

    IsStandard: bool  # readonly
    Mass: float  # readonly
    MassSigma: float  # readonly
    NonemtySampleCount: int  # readonly
    ObjectList: List[Mfe.INormalizedObject]  # readonly
    SampleCount: int  # readonly
    StandardTime: float  # readonly
    StandardType: Mfe.ObjectCorrelator.StandardUsage  # readonly

    def GetTime(self, corrected: bool) -> float: ...
    def GetTimeSigma(self, corrected: bool) -> float: ...
    def GetAverageAbundance(
        self, start: int, end: int, treatNullAsZero: bool, normalized: bool
    ) -> float: ...
    def GetMass(self, startSampleIndex: int, endSampleIndex: int) -> float: ...
    def SetObject(self, sampleIndex: int, compound: Mfe.INormalizedObject) -> None: ...
    def GetAbundanceSigma(
        self, start: int, end: int, treatNullAsZero: bool, normalized: bool
    ) -> float: ...

class CefCompound:  # Class
    def __init__(self) -> None: ...

    Formula: str
    IsotopeClusters: Sequence[Mfe.CefIsotopeCluster]
    Name: str
    RetentionTime: float

class CefFile2:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Read(
        filePath: str,
        extractor: PrecursorIsotopeClusterExtractor,
        setChargeCarrierToProton: bool,
    ) -> List[ICompoundPrecursorProductDataSet]: ...
    @staticmethod
    def ReadCompounds(filePath: str) -> Sequence[Mfe.CefCompound]: ...

class CefIsotopeCluster:  # Class
    def __init__(self) -> None: ...

    IonSpecies: IModificationSpecies
    PeakList: List[SpectralPeak]

class ChromatographyParameters(IRetentionTimePeakFinderParameters):  # Class
    def __init__(self) -> None: ...

    RetentionTimePeakWidth: float
    SmoothingStrength: float

class CompoundFormationParameters(
    Mfe.IEngineBlockUserParameters,
    Mfe.ICompoundFormationParameters,
    IChemicalAndIonizationParameters,
):  # Class
    def __init__(self) -> None: ...

    IonizationInstruction: Mfe.IonizationInstruction  # readonly
    IonizationInstructionNegativeCase: Mfe.IonizationInstruction  # readonly
    IonizationInstructionPositiveCase: Mfe.IonizationInstruction  # readonly
    IsotopeCharacter: Mfe.IsotopeCharacter
    MaxChargeCount: int
    NeutralModifiers: List[IModificationUnit]
    TargetedMassList: Mfe.TargetedMassList  # readonly

    def SetEffectiveChargeAssignmentInstruction(
        self, polarity: SpectrumSetMetadata.MSPolarity
    ) -> None: ...
    def IsEquivalent(self, another: Mfe.CompoundFormationParameters) -> bool: ...
    def FromXml(self, siblings: System.Xml.XmlNodeList) -> None: ...
    def Clone(self) -> Mfe.CompoundFormationParameters: ...
    def ToXml(self, document: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class DataRangeParameters(IDataRangeParameters):  # Class
    def __init__(self) -> None: ...

    MaxMZ: float  # readonly
    MaxRetentionTime: float  # readonly
    MinMZ: float  # readonly
    MinRetentionTime: float  # readonly

    def SetMZRange(self, min: float, max: float) -> None: ...
    def SetRetentionTimeRange(self, min: float, max: float) -> None: ...

class Event:  # Class
    ApexCount: int  # readonly
    def __getitem__(self, localIndex: int) -> float: ...
    Length: int  # readonly
    StartIndex: int  # readonly

    def GetApexHeight(self, apexIndex: int) -> float: ...
    def GetApexLocalLocation(self, apexIndex: int) -> int: ...

class ICompoundFormationParameters(Mfe.IEngineBlockUserParameters):  # Interface
    IsotopeCharacter: Mfe.IsotopeCharacter
    MaxChargeCount: int

class IDataSelectionParameters(object):  # Interface
    MaxMZ: float  # readonly
    MaxRetentionTime: float  # readonly
    MinMZ: float  # readonly
    MinRetentionTime: float  # readonly
    RTSmoothingHalfTaperSpan: float

    def SetMZRange(self, min: float, max: float) -> None: ...
    def SetRetentionTimeRange(self, min: float, max: float) -> None: ...

class IEngineBlockUserParameters(object):  # Interface
    ...

class IMfeCompoundParameters(Mfe.IMfeUserParameters):  # Interface
    CompoundFormationParameters: Mfe.ICompoundFormationParameters  # readonly
    Peak3DDetectionParameters: Mfe.IPeak3DDetectionParameters  # readonly

class IMfeProteinParameters(Mfe.IMfeUserParameters):  # Interface
    Peak3DDetectionParameters: Mfe.IPeak3DDetectionParameters  # readonly
    ProteinFormationParameters: Mfe.IProteinFormationParameters  # readonly

class IMfeUserParameters(object):  # Interface
    PeakFindParameters: Mfe.IPeakFindParameters  # readonly

    def Clone(self) -> Mfe.IMfeUserParameters: ...

class INormalizedObject(object):  # Interface
    InputObject: IMass_TimeSeparatedObject  # readonly
    Mass: float  # readonly
    NormalizationFactor: float  # readonly

    def GetTime(self, corrected: bool) -> float: ...
    def GetAbundance(self, useNormalized: bool) -> float: ...

class IPeak3DDetectionParameters(Mfe.IEngineBlockUserParameters):  # Interface
    MaxNumberOfSpectralPeaks: int

class IPeakFindParameters(Mfe.IEngineBlockUserParameters):  # Interface
    ChromatographyParameters: Mfe.ChromatographyParameters  # readonly
    DataRangeParameters: Mfe.DataRangeParameters  # readonly
    SpectralPeakFinderParameters: SpectralPeakFinderParameters  # readonly

class IProteinFormationParameters(Mfe.IEngineBlockUserParameters):  # Interface
    ...

class ISpectralPeakPicker(object):  # Interface
    def FindPeaks(
        self,
        spectrum: List[float],
        events: List[Mfe.Event],
        peakWidthModel: IFunction,
        minDistance: float,
        maxValleyHeightForDecoupled: float,
        heightThreshold: IFunction,
        rejectOverlappingPeaks: bool,
    ) -> List[PeakAdapter]: ...

class IonizationInstruction(IIonSpeciesGroupingRules):  # Class
    def __init__(self, polarity: SpectrumSetMetadata.MSPolarity) -> None: ...

    Adducts: List[Mfe.IonizationInstruction.Adduct]
    DefaulChargeUnit: IModificationUnit

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, another: Mfe.IonizationInstruction) -> bool: ...
    def GetHashCode(self) -> int: ...
    def FromXml(self, data: System.Xml.XmlElement) -> None: ...
    def Clone(self) -> Mfe.IonizationInstruction: ...
    def ToXml(
        self, document: System.Xml.XmlDocument, title: str
    ) -> System.Xml.XmlElement: ...

    # Nested Types

    class Adduct:  # Struct
        def __init__(self, ChargeUnit: IModificationUnit, isAncher: bool) -> None: ...

        ChargeUnit: IModificationUnit  # readonly
        IsAnchor: bool

        def Clone(self) -> Mfe.IonizationInstruction.Adduct: ...

class IsotopeCharacter(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AllElements: Mfe.IsotopeCharacter = ...  # static # readonly
    Averagine: Mfe.IsotopeCharacter = ...  # static # readonly
    Biological: Mfe.IsotopeCharacter = ...  # static # readonly
    C_Halogen: Mfe.IsotopeCharacter = ...  # static # readonly
    C_OneLi: Mfe.IsotopeCharacter = ...  # static # readonly
    Glycan: Mfe.IsotopeCharacter = ...  # static # readonly

class MS2File:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def ReadData(
        filePath: str,
        precursorPeaks: List[SpectralPeak],
        precursorZ: int,
        precursorIonSpecies: IModificationSpecies,
        productPeaks: List[SpectralPeak],
    ) -> bool: ...

class MfeCompoundParameters(
    Mfe.IMfeCompoundParameters, Mfe.IMfeUserParameters
):  # Class
    def __init__(self) -> None: ...

    CompoundFormationParameters: Mfe.ICompoundFormationParameters
    Peak3DDetectionParameters: Mfe.IPeak3DDetectionParameters
    PeakFindParameters: Mfe.IPeakFindParameters

    def Clone(self) -> Mfe.IMfeUserParameters: ...

class MfeInfusionParameters(Mfe.IMfeUserParameters):  # Class
    def __init__(self) -> None: ...

    CompoundFormationParameters: Mfe.ICompoundFormationParameters
    PeakFindParameters: Mfe.IPeakFindParameters

    def Clone(self) -> Mfe.IMfeUserParameters: ...

class MfeProteinParameters(Mfe.IMfeProteinParameters, Mfe.IMfeUserParameters):  # Class
    def __init__(self) -> None: ...

    Peak3DDetectionParameters: Mfe.IPeak3DDetectionParameters
    PeakFindParameters: Mfe.IPeakFindParameters
    ProteinFormationParameters: Mfe.IProteinFormationParameters

    def Clone(self) -> Mfe.IMfeUserParameters: ...

class MmcFile:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Read(
        filePath: str, extractor: PrecursorIsotopeClusterExtractor
    ) -> ICompoundPrecursorProductDataSet: ...

class ObjectCorrelator:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Run(
        objectLists: List[Sequence[IMass_TimeSeparatedObject]],
        customerNormalizationFactors: List[float],
        parameters: Mfe.ObjectCorrelator.UserParameters,
    ) -> List[Mfe.Bucket]: ...

    # Nested Types

    class CalibrationStandard:  # Struct
        Mass: float
        StandardUsage: Mfe.ObjectCorrelator.StandardUsage
        Time: float

    class IntensityNormalizationChoice(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        UseCustomerFactor: Mfe.ObjectCorrelator.IntensityNormalizationChoice = (
            ...
        )  # static # readonly
        UseOverallAbundance: Mfe.ObjectCorrelator.IntensityNormalizationChoice = (
            ...
        )  # static # readonly
        UseOverallHeight: Mfe.ObjectCorrelator.IntensityNormalizationChoice = (
            ...
        )  # static # readonly
        UseStandardsByAbundance: Mfe.ObjectCorrelator.IntensityNormalizationChoice = (
            ...
        )  # static # readonly
        UseStandardsByHeight: Mfe.ObjectCorrelator.IntensityNormalizationChoice = (
            ...
        )  # static # readonly

    class StandardUsage(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        AbundanceOnly: Mfe.ObjectCorrelator.StandardUsage = ...  # static # readonly
        TimeAndAbundance: Mfe.ObjectCorrelator.StandardUsage = ...  # static # readonly
        TimeOnly: Mfe.ObjectCorrelator.StandardUsage = ...  # static # readonly

    class TimeCorrectionChoice(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        Auto: Mfe.ObjectCorrelator.TimeCorrectionChoice = ...  # static # readonly
        UseStandards: Mfe.ObjectCorrelator.TimeCorrectionChoice = (
            ...
        )  # static # readonly

    class UserParameters:  # Class
        def __init__(self) -> None: ...

        CustomerSampleNormalizationFactors: List[float]
        IntensityNormalizationChoice: Mfe.ObjectCorrelator.IntensityNormalizationChoice
        MassToleranceFunction: IFunction
        Standards: List[Mfe.ObjectCorrelator.CalibrationStandard]
        TimeCorrectionChoice: Mfe.ObjectCorrelator.TimeCorrectionChoice
        TimeToleranceFunctionForCorrection: IFunction
        TimeToleranceFunctionForCorrelation: IFunction

        def FromXml(self, siblings: System.Xml.XmlNodeList) -> None: ...
        @staticmethod
        def CreateRtInsensitiveParameters(
            userInput: Mfe.ObjectCorrelator.UserParameters,
        ) -> Mfe.ObjectCorrelator.UserParameters: ...
        def ToXml(self, document: System.Xml.XmlDocument) -> System.Xml.XmlElement: ...

class PeakFindParameters(
    Mfe.IPeakFindParameters, Mfe.IEngineBlockUserParameters
):  # Class
    def __init__(self) -> None: ...

    ChromatographyParameters: Mfe.ChromatographyParameters  # readonly
    DataRangeParameters: Mfe.DataRangeParameters  # readonly
    SpectralPeakFinderParameters: SpectralPeakFinderParameters  # readonly

    def Clone(self) -> Mfe.PeakFindParameters: ...

class PeakFinder:  # Class
    def __init__(
        self,
        userParameters: SpectralPeakFinderParameters,
        peakWidthInMZ: IFunction,
        tofDataTimeInterval: float,
    ) -> None: ...

    NoninterestingMZ: float  # static # readonly

    def PeakFullyProcessedData(self) -> MSProfile: ...
    def PeekBaseline(self) -> MSProfile: ...
    def FindPeaks(self, raw: MSProfile) -> PeakList: ...
    def PeakIntensityThresholdLevel(self) -> MSProfile: ...
    def PeekSmoothedData(self) -> MSProfile: ...
    def PeekBaselineRemovedData(self) -> MSProfile: ...

class ProteinFormationParameters(
    IProteinFinderParameters,
    Mfe.IEngineBlockUserParameters,
    Mfe.IProteinFormationParameters,
):  # Class
    def __init__(self) -> None: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, another: Mfe.ProteinFormationParameters) -> bool: ...
    def GetHashCode(self) -> int: ...
    def Clone(self) -> Mfe.ProteinFormationParameters: ...

class TargetedMassList(ITargetedMassList):  # Class
    def __init__(self) -> None: ...

    Length: int  # readonly
    ToleranceFunction: IFunction  # readonly

    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(self, another: Mfe.TargetedMassList) -> bool: ...
    def GetHashCode(self) -> int: ...
    def Clone(self) -> Mfe.TargetedMassList: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .UI import UIContext

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ReportMethodEdit.UAControls

class IonPeaksGraphicsControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, context: UIContext) -> None: ...
    def Apply(self) -> bool: ...

class IonPeaksGraphicsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, context: UIContext) -> None: ...

class SampleChromatogramGraphicsControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, context: UIContext) -> None: ...
    def Apply(self) -> bool: ...

class SampleChromatogramGraphicsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, context: UIContext) -> None: ...

class SpectramGraphicsControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, context: UIContext) -> None: ...
    def Apply(self) -> bool: ...

class SpectrumGraphicsDialog(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, context: UIContext) -> None: ...

class UAGraphicsControl(
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UserControl,
):  # Class
    def __init__(self) -> None: ...
    def Initialize(self, context: UIContext) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Properties

class Resources:  # Class
    ActionString_GenerateReport: str  # static # readonly
    AnalysisMessageTarget_Sample: str  # static # readonly
    AppIcon: System.Drawing.Icon  # static # readonly
    AppName: str  # static # readonly
    AppName_Short: str  # static # readonly
    BlankSubtractPeakThresholdType_ComponentArea: str  # static # readonly
    BlankSubtractPeakThresholdType_EstimatedConcentration: str  # static # readonly
    BlankSubtractPeakThresholdType_None: str  # static # readonly
    BlankSubtractRTWindowType_FullWidthHalfMaximum: str  # static # readonly
    BlankSubtractRTWindowType_Minutes: str  # static # readonly
    BlankSubtractRTWindowType_None: str  # static # readonly
    BmpError: System.Drawing.Bitmap  # static # readonly
    BmpInformation: System.Drawing.Bitmap  # static # readonly
    BmpWarning: System.Drawing.Bitmap  # static # readonly
    ButtonLabel_NewAnalysis: str  # static # readonly
    Category_All: str  # static # readonly
    Category_BasePeak: str  # static # readonly
    Category_Component: str  # static # readonly
    Category_DeconvolutionMethod: str  # static # readonly
    Category_ExactMass: str  # static # readonly
    Category_Hit: str  # static # readonly
    Category_LibrarySearchMethod: str  # static # readonly
    Category_ModelPeakIon: str  # static # readonly
    Category_Peak: str  # static # readonly
    Category_Sample: str  # static # readonly
    Category_TargetCompound: str  # static # readonly
    Collapse: System.Drawing.Bitmap  # static # readonly
    Copy: System.Drawing.Bitmap  # static # readonly
    Culture: System.Globalization.CultureInfo  # static
    DeconvolutionMethod_BatchID: str  # static # readonly
    DeconvolutionMethod_SampleID: str  # static # readonly
    DialogResult_AddSamples: str  # static # readonly
    DialogTitle_AddSamples: str  # static # readonly
    DialogTitle_Analyze: str  # static # readonly
    DialogTitle_CompressResults: str  # static # readonly
    DialogTitle_Export: str  # static # readonly
    DialogTitle_ExportTableToLibrary: str  # static # readonly
    DialogTitle_ImportQuantBatch: str  # static # readonly
    DialogTitle_LoadMethod: str  # static # readonly
    DialogTitle_NewAnalysis: str  # static # readonly
    DialogTitle_OpenAnalysis: str  # static # readonly
    DialogTitle_Properties: str  # static # readonly
    DialogTitle_Query: str  # static # readonly
    DialogTitle_RTCalibration: str  # static # readonly
    DialogTitle_RunScript: str  # static # readonly
    DialogTitle_SaveAnalysis: str  # static # readonly
    DialogTitle_SaveAnalysisAs: str  # static # readonly
    DialogTitle_SaveMethod: str  # static # readonly
    Err_ApplicationIsInModalState: str  # static # readonly
    Err_CannotGenerateReportReadOnlyAuditTrail: str  # static # readonly
    Err_ConfigurationError: str  # static # readonly
    Err_Error: str  # static # readonly
    Err_ErrorWhileAnalyzing: str  # static # readonly
    Err_FileAlreadyExists: str  # static # readonly
    Err_LayoutFileVersionNotMatch: str  # static # readonly
    Err_LogonRequired: str  # static # readonly
    Err_PleaseEnter: str  # static # readonly
    Err_PleaseEnterValidNumber: str  # static # readonly
    Err_PleaseEnterValidNumbers: str  # static # readonly
    Err_ReportError: str  # static # readonly
    Err_SpecifyUserName: str  # static # readonly
    Err_TranslatorNotInstalled: str  # static # readonly
    Expand: System.Drawing.Bitmap  # static # readonly
    ExportDestinationType_Csv: str  # static # readonly
    ExportDestinationType_Library: str  # static # readonly
    ExportDestinationType_QuantMethod: str  # static # readonly
    FileType_AllFiles: str  # static # readonly
    FileType_CSVFiles: str  # static # readonly
    FileType_LayoutFiles: str  # static # readonly
    FileType_MethodFiles: str  # static # readonly
    FileType_Methods: str  # static # readonly
    FileType_QuantMethod: str  # static # readonly
    FileType_QueryFiles: str  # static # readonly
    FileType_RTCalibrationFiles: str  # static # readonly
    FileType_ReportTemplateFiles: str  # static # readonly
    FileType_ScriptFiles: str  # static # readonly
    FileType_UnknownsAnalysisFiles: str  # static # readonly
    FileType_XmlFiles: str  # static # readonly
    FillDown: System.Drawing.Bitmap  # static # readonly
    HitConcentrationEstimation_AverageRFofAllISTDs: str  # static # readonly
    HitConcentrationEstimation_AverageRFofAllTargets: str  # static # readonly
    HitConcentrationEstimation_AverageRFofClosestTarget: str  # static # readonly
    HitConcentrationEstimation_ManualRF: str  # static # readonly
    HitConcentrationEstimation_None: str  # static # readonly
    HitConcentrationEstimation_RFofClosestISTD: str  # static # readonly
    HitConcentrationEstimation_RFofClosestTargetISTD: str  # static # readonly
    HitConcentrationEstimation_RelativeISTDEstimation: str  # static # readonly
    IntegratorType_Agile: str  # static # readonly
    IntegratorType_Agile2: str  # static # readonly
    IonPeakLabel_Component: str  # static # readonly
    IonPeakLabel_TIC: str  # static # readonly
    Label_Automatic: str  # static # readonly
    Label_Component: str  # static # readonly
    Label_NoDisplay: str  # static # readonly
    Label_None: str  # static # readonly
    Label_ReadOnly: str  # static # readonly
    Label_StoppingAnalysis: str  # static # readonly
    Legend_Components: str  # static # readonly
    LibrarySearchTool_SetBestHit: str  # static # readonly
    LibrarySearchType_AccurateMassPatternMatch: str  # static # readonly
    LibrarySearchType_RetentionTimeMatch: str  # static # readonly
    LibrarySearchType_SpectralSearch: str  # static # readonly
    MSLibraryFormat_Binary: str  # static # readonly
    MSLibraryFormat_Compressed: str  # static # readonly
    MSLibraryFormat_PCDL: str  # static # readonly
    MSLibraryFormat_XML: str  # static # readonly
    MethodFromLibraryIonMode_HighestMass: str  # static # readonly
    MethodFromLibraryIonMode_Monoisotopic: str  # static # readonly
    MethodFromLibraryIonMode_MostAbundant: str  # static # readonly
    MethodFromLibraryIonMode_Weighted: str  # static # readonly
    Msg_CannotRecognizeLayoutFile: str  # static # readonly
    Msg_ChooseBatchFileInSameBatchFolder: str  # static # readonly
    Msg_ConvertingSample: str  # static # readonly
    Msg_GeneratingReportsPleaseWait: str  # static # readonly
    Msg_LoggingIn: str  # static # readonly
    Msg_ProcessWasStoppedByUser: str  # static # readonly
    Msg_SelectCellsToCopy: str  # static # readonly
    Msg_SelectOneComponent: str  # static # readonly
    Msg_SelectOneSampleToEditMethod: str  # static # readonly
    Msg_SelectOneSampleToReport: str  # static # readonly
    Msg_SelectOneSampleToSaveMethod: str  # static # readonly
    MultiLibrarySearchType_All: str  # static # readonly
    MultiLibrarySearchType_StopWhenFirstFoundInFirstLibrary: str  # static # readonly
    MultiLibrarySearchType_StopWhenFound: str  # static # readonly
    MzDeltaUnits_AMU: str  # static # readonly
    MzDeltaUnits_PPM: str  # static # readonly
    MzDeltaUnits_Percent: str  # static # readonly
    PaneTitle_ComponentChromatogram: str  # static # readonly
    PaneTitle_ComponentSpectrum: str  # static # readonly
    PaneTitle_EIC: str  # static # readonly
    Pane_AnalysisMessage: str  # static # readonly
    Pane_Chromatogram: str  # static # readonly
    Pane_ComponentTable: str  # static # readonly
    Pane_EicPeaks: str  # static # readonly
    Pane_ExactMass: str  # static # readonly
    Pane_HitTable: str  # static # readonly
    Pane_Hits: str  # static # readonly
    Pane_IonPeaks: str  # static # readonly
    Pane_SampleTable: str  # static # readonly
    Pane_Script: str  # static # readonly
    Pane_Spectrum: str  # static # readonly
    Pane_Structure: str  # static # readonly
    Pane_TargetTable: str  # static # readonly
    PeakDetectionAlgorithm_FeatureDeconvolution: str  # static # readonly
    PeakDetectionAlgorithm_SpectralDeconvolution: str  # static # readonly
    PeakDetectionAlgorithm_TICAnalysis: str  # static # readonly
    PeakDetectionAlgorithm_TargetDeconvolution: str  # static # readonly
    PeakDetectionAlgorithm_TargetDeconvolution_SureTarget: str  # static # readonly
    PeakLabel_RTUnit_Minites: str  # static # readonly
    Progress_CompressingResults: str  # static # readonly
    Progress_Deconvolutiong: str  # static # readonly
    Progress_ExportingTableToLibrary: str  # static # readonly
    Progress_FindingTICPeaks: str  # static # readonly
    Progress_Identifying: str  # static # readonly
    Progress_ImportingComponentTable: str  # static # readonly
    Progress_ImportingQuantBatch: str  # static # readonly
    Progress_MatchingTarget: str  # static # readonly
    Progress_OpeningAnalysis: str  # static # readonly
    Progress_RunningScript: str  # static # readonly
    Progress_SavingAnalysis: str  # static # readonly
    Prompt_MethodFileExistsOverwrite: str  # static # readonly
    Prompt_SaveAnalysis: str  # static # readonly
    Prompt_SaveAnalysisBeforeReport: str  # static # readonly
    Prompt_UndoCheckoutAnalysis: str  # static # readonly
    Prompt_YouMadeChangesApply: str  # static # readonly
    Prompt_YouMadeChangesApplyToAllSamples: str  # static # readonly
    PropertyPageTitle_ChromatogramProperties: str  # static # readonly
    PropertyPageTitle_EicPeaks: str  # static # readonly
    PropertyPageTitle_IonPeaks: str  # static # readonly
    PropertyPageTitle_SpectrumProperties: str  # static # readonly
    RTMatchFactorType_Gaussian: str  # static # readonly
    RTMatchFactorType_None: str  # static # readonly
    RTMatchFactorType_Trapezoidal: str  # static # readonly
    RTPenaltyType_Additive: str  # static # readonly
    RTPenaltyType_Multiplicative: str  # static # readonly
    Refresh: System.Drawing.Bitmap  # static # readonly
    Remoting_QuantBatchNotExist: str  # static # readonly
    ResourceManager: System.Resources.ResourceManager  # static # readonly
    ScreeningType_Fast: str  # static # readonly
    ScreeningType_None: str  # static # readonly
    ScreeningType_Normal: str  # static # readonly
    SpectrumPeakWeighting_EqualWeight: str  # static # readonly
    SpectrumPeakWeighting_Mass: str  # static # readonly
    SpectrumPeakWeighting_Mass2: str  # static # readonly
    SpectrumPeakWeighting_Mass3: str  # static # readonly
    Title_CopySamples: str  # static # readonly
    Title_EicPeaks: str  # static # readonly
    Title_LoggingIn: str  # static # readonly
    Tools: List[int]  # static # readonly
    Usage: str  # static # readonly
